@@ -9,7 +9,7 @@ USER_MODEL = get_user_model()
 
 @admin.register(DjangoGlobalLog)
 class LogAdmin(admin.ModelAdmin):
-    list_display = ["id", "operator_name", "path", "code", "ip", "create_at"]
+    list_display = ["id", "operator_name", "method", "path", "code", "ip", "create_at"]
     list_filter = ["code"]
 
     @admin.display(description=_("操作人"))
